fn InitFileSink() -> &'static Mutex<Option<BufWriter<File>>>Expand description
Initialise the file sink on first call. Silently falls through to a disabled sink if the directory or file can’t be created - the caller must never panic because of a log-file failure.